@@ -138,7 +138,15 @@ sub install_app_darwin {
 }
 
 sub install_app_freebsd {
-    my ($app, $info ) = @_;
+    my ( $app, $info ) = @_;
+
+    if ( -x '/usr/sbin/pkg' ) {
+        if ( `/usr/sbin/pkg info -x $app` ) {  ## no critic (Backtick)
+            return print "$app is installed.\n";
+        }
+        print "installing $app";
+        return if install_app_freebsd_pkg($info, $app);
+    }
 
     print " from ports...";
 
@@ -147,13 +155,13 @@ sub install_app_freebsd {
             return print "$app is installed.\n";
         };
     }
-    if ( -x '/usr/sbin/pkg') {
-        if ( `/usr/sbin/pkg info -x $app` ) {  ## no critic (Backtick)
-            return print "$app is installed.\n";
-        }
-    }
 
     print "installing $app";
+    return install_app_freebsd_port($app, $info);
+};
+
+sub install_app_freebsd_port {
+    my ( $app, $info ) = @_;
 
     my $name = $info->{port} || $app;
     my $category = $info->{category} || '*';
@@ -168,6 +176,26 @@ sub install_app_freebsd {
     return;
 };
 
+sub install_app_freebsd_pkg {
+    my ( $info, $app ) = @_;
+    my $pkg = '/usr/sbin/pkg';
+    if (! -x $pkg) {
+        warn "$pkg not installed\n";
+        return;
+    };
+    my $name = $info->{port} || $app;
+    print "installing $name\n";
+    system "$pkg install -y $name";
+    return 1 if `$pkg info -x $name`;
+
+    return 0 if ($app eq $name);
+
+    system "$pkg install -y $app";
+    return 1 if `$pkg info -x $app`;
+
+    return 0;
+};
+
 sub install_app_linux {
     my ($app, $info ) = @_;
 
@@ -252,9 +280,21 @@ sub install_module_freebsd {
     my ($module, $info, $version) = @_;
 
     my $name = $info->{port} || $module;
-    my $portname = "p5-$name";
+    my $portname = substr($name, 0, 3) eq 'p5-' ? $name : "p5-$name";
     $portname =~ s/::/-/g;
 
+    if ( -x '/usr/sbin/pkg' ) {
+        if ( `/usr/sbin/pkg info -x $portname` ) { ## no critic (Backtick)
+            return print "$module is installed.\n";
+        }
+        return 1 if install_module_freebsd_pkg($portname);
+    }
+
+    return install_module_freebsd_port($portname, $info, $module);
+}
+
+sub install_module_freebsd_port {
+    my ($portname, $info, $module) = @_;
     print " from ports...$portname...";
 
     if ( -x '/usr/sbin/pkg_info' ) {
@@ -262,11 +302,6 @@ sub install_module_freebsd {
             return print "$module is installed.\n";
         }
     }
-    if ( -x '/usr/sbin/pkg' ) {
-        if ( `/usr/sbin/pkg info -x $portname` ) { ## no critic (Backtick)
-            return print "$module is installed.\n";
-        }
-    }
 
     print "installing $module ...";
 
@@ -284,6 +319,19 @@ sub install_module_freebsd {
     return;
 }
 
+sub install_module_freebsd_pkg {
+    my ( $module ) = @_;
+    my $pkg = '/usr/sbin/pkg';
+    if (! -x $pkg) {
+        warn "pkg not installed!\n";
+        return 0;
+    }
+    print "installing $module\n";
+    system "$pkg install -y $module";
+    return 1 if `$pkg info -x $module`;
+    return 0;
+};
+
 sub install_module_linux {
     my ($module, $info, $version) = @_;
 
@@ -379,10 +427,10 @@ sub name_overrides {
 # couple rules. When that doesn't work, add entries here for FreeBSD (port),
 # MacPorts ($dport), yum, and apt.
     my @modules = (
-        { module=>'LWP::UserAgent', info => { cat=>'www', port=>'libwww', dport=>'p5-libwww-perl', yum=>'perl-libwww-perl' }, },
+        { module=>'LWP::UserAgent', info => { cat=>'www', port=>'p5-libwww', dport=>'p5-libwww-perl', yum=>'perl-libwww-perl' }, },
         { module=>'Mail::Send'    , info => { port => 'Mail::Tools', }  },
         { module=>'Date::Parse'   , info => { port => 'TimeDate',    }  },
-        { module=>'LWP'           , info => { port => 'libwww',      }  },
+        { module=>'LWP'           , info => { port => 'p5-libwww',   }  },
     );
     my ($match) = grep { $_->{module} eq $mod } @modules;
     return $match if $match;
